@@ -7,4 +7,4 @@ __all__ = []
 
 @B.dispatch
 def rank(a: AbstractMatrix):
-    return 2
+    return len(B.shape(a))
